@@ -86,7 +86,7 @@
 #define KI18NLOCALEDATA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KI18NLOCALEDATA_NO_DEPRECATED
-#  define KI18NLOCALEDATA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
+#  define KI18NLOCALEDATA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KI18NLOCALEDATA_NO_DEPRECATED_WARNINGS
 #  define KI18NLOCALEDATA_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KI18NLOCALEDATA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KI18NLOCALEDATA_DEPRECATED_WARNINGS_SINCE KI18NLOCALEDATA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KI18NLOCALEDATA_DEPRECATED_WARNINGS_SINCE 0x55d00
+#    define KI18NLOCALEDATA_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
@@ -164,7 +164,7 @@
 #define KI18NLOCALEDATA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KI18NLOCALEDATA_NO_DEPRECATED
-#  define KI18NLOCALEDATA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
+#  define KI18NLOCALEDATA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KI18NLOCALEDATA_NO_DEPRECATED_WARNINGS
 #  define KI18NLOCALEDATA_DEPRECATED_WARNINGS_SINCE 0
@@ -174,7 +174,7 @@
 #  ifdef KI18NLOCALEDATA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KI18NLOCALEDATA_DEPRECATED_WARNINGS_SINCE KI18NLOCALEDATA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KI18NLOCALEDATA_DEPRECATED_WARNINGS_SINCE 0x55d00
+#    define KI18NLOCALEDATA_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
